import { BatchDBOp, CacheKey, PruneStats, SortKeyCache, SortKeyCacheResult } from 'warp-contracts';
import { SortKeyCacheRangeOptions } from 'warp-contracts/lib/types/cache/SortKeyCacheRangeOptions';
import { PgSortKeyCacheOptions } from './PgSortKeyCacheOptions';
export declare class PgSortKeyCache<V> implements SortKeyCache<V> {
    private readonly pgCacheOptions;
    private readonly logger;
    private readonly tableName;
    private readonly schemaName;
    private pool;
    private client;
    constructor(pgCacheOptions: PgSortKeyCacheOptions);
    private createTableIfNotExists;
    begin(): Promise<void>;
    close(): Promise<void>;
    commit(): Promise<void>;
    delete(key: string): Promise<void>;
    dump(): Promise<any>;
    get(cacheKey: CacheKey): Promise<SortKeyCacheResult<V> | null>;
    getLast(key: string): Promise<SortKeyCacheResult<V> | null>;
    getLastSortKey(): Promise<string | null>;
    getLessOrEqual(key: string, sortKey: string): Promise<SortKeyCacheResult<V> | null>;
    open(): Promise<void>;
    private connection;
    /**
     Let's assume that given contract cache contains these sortKeys: [a, b, c, d, e, f]
     Let's assume entriesStored = 2
     After pruning, the cache should be left with these keys: [e,f].
  
     const entries = await contractCache.keys({ reverse: true, limit: entriesStored }).all();
     This would return in this case entries [f, e] (notice the "reverse: true").
  
     await contractCache.clear({ lt: entries[entries.length - 1] });
     This effectively means: await contractCache.clear({ lt: e });
     -> hence the entries [a,b,c,d] are removed and left are the [e,f]
     */
    prune(entriesStored?: number): Promise<PruneStats>;
    put(stateCacheKey: CacheKey, value: V): Promise<void>;
    private removeOldestEntries;
    rollback(): Promise<void>;
    storage<S>(): S;
    drop(): Promise<void>;
    batch(opStack: BatchDBOp<V>[]): Promise<any>;
    del(cacheKey: CacheKey): Promise<void>;
    keys(sortKey: string, options?: SortKeyCacheRangeOptions): Promise<string[]>;
    kvMap(sortKey: string, options?: SortKeyCacheRangeOptions): Promise<Map<string, V>>;
}
//# sourceMappingURL=PgSortKeyCache.d.ts.map